#!/bin/bash
#
# Adapt then export the sysroots into tarball
# Generate a script to install the tarball and set up environment for SDK
#

MACHINE=${machine}

outputDir=${PLATFORM_LOC}/sdk

# Create temporary workdir
WORKDIR=$(mktemp -d -t tmp-XXXXXXXXXX)
trap "rm -rf ${WORKDIR}" EXIT
cd ${WORKDIR}

SDK_DIR=${WORKDIR}/sdk-${MACHINE}
SDK_SYSROOTS_DIR=${SDK_DIR}/sysroots
mkdir -p ${SDK_SYSROOTS_DIR}

#TODO add option
#
#	- to change output dir
#	- to change sdk name
#	
#


# Export Native sysroot
if [ -d ${NATIVE_SYSROOT_LOC} ]; then
	fatal 1 "Native sysroot does not exist"
fi

log "Exporting native sysroots into SDK..."
cp -r ${NATIVE_SYSROOT_LOC} ${SDK_SYSROOTS_DIR}
SDK_NATIVE_SYSROOT_DIRNAME="$(basename ${NATIVE_SYSROOT_LOC})"
SDK_CROSS_COMPILER_PATH="${CROSS_COMPILER_PATH##${NATIVE_SYSROOT_LOC}}"
SDK_CROSS_COMPILER_LOC="${CROSS_COMPILER_LOC##${NATIVE_SYSROOT_LOC}}"
SDK_CROSS_PREFIX="${CROSS_PREFIX}"
log "Exporting native sysroots into SDK... done"

# Export Target sysroot
if [ -d ${TARGET_SYSROOT_LOC} ]; then
	fatal 1 "Target sysroot does not exist"
fi

log "Exporting native sysroots into SDK..."
cp -r ${TARGET_SYSROOT_LOC} ${SDK_SYSROOTS_DIR}
SDK_TARGET_SYSROOT_DIRNAME="$(basename $TARGET_SYSROOT_LOC)"
log "Exporting native sysroots into SDK... done"


echo Creating environnement setup script
cat <<- EOF >> setup-environnement-${MACHINE}.sh
#!/bin/bash

# Export environment variable
echo "Sourcing environment variables..."
export SDK_LOC=$( cd -- "\$( dirname -- "\${BASH_SOURCE[0]}" )" &> /dev/null && pwd )
export SYSROOT_LOC="\${SDK_LOC}/${SDK_TARGET_SYSROOT_DIRNAME}"
export NATIVE_SYSROOT_LOC="\${SDK_LOC}/${SDK_NATIVE_SYSROOT_DIRNAME}"
export TARGET_SYSROOT_LOC=\"${SDK_LOC}/${SDK_TARGET_SYSROOT_DIRNAME}"
export arch_options="${arch_options}"
export arch_as_options="\${arch_options} ${as_options}"
export arch_gcc_options="\${arch_options} ${gcc_options}"
export arch_gPP_options="\${arch_options} ${gPP_options}"
export arch_ld_options="\${arch_options} ${ld_options}"
export includedir="\${SYSROOT_LOC}/usr/include"
export arch_name="${arch_name}"
export arch_triplet="${arch_triplet}"
export arch_compiler_prefix="${arch_name}-${arch_triplet}"
export CROSS_PREFIX=${SDK_CROSS_PREFIX}
export CFLAGS="-O2 -pipe"
export CCLD=${arch_compiler_prefix}-gcc
export STRIP=${arch_compiler_prefix}-strip
export CXXLD=${arch_compiler_prefix}-g++
export RANLIB=${arch_compiler_prefix}-ranlib
export OBJDUMP=${arch_compiler_prefix}-objdump
export AS=${arch_compiler_prefix}-as
export AR=${arch_compiler_prefix}-ar
export NM=${arch_compiler_prefix}-nm
export CROSS_COMPILE=${arch_compiler_prefix}-
export STRINGS=${arch_compiler_prefix}-strings
export compiler_prefix=${SDK_CROSS_PREFIX}
export CROSS_COMPILER_PATH="\${NATIVE_SYSROOT_LOC}/${SDK_CROSS_COMPILER_PATH}"
export compiler_loc="\${NATIVE_SYSROOT_LOC}/${CROSS_COMPILER_LOC}"
export CPP="${arch_compiler_prefix}-gcc -E"
export LD=${arch_compiler_prefix}-ld
export CC=${arch_compiler_prefix}-gcc
export READELF=${arch_compiler_prefix}-readelf         

# Export new PATH environment variable
export PATH=\${NATIVE_SYSROOT_LOC}/bin:\${NATIVE_SYSROOT_LOC}/usr/bin:\${CROSS_COMPILER_PATH}:\${PATH}

echo "Rewriting old hard path (it might takes some times)..."
# Find and replace all the remaining hard path
find \${SDK_LOC}/sysroots -type f ! -perm /0111 -print0 | xargs -0 sed -i -e "s/@@SDK_PATH_PLACEHOLDER@@/\${SDK_LOC//\//\\/}/g"

EOF

chmod +x setup-environnement-${MACHINE}.sh

echo "Removing old hard path"
find ${SDK_DIR} -type f ! -perm /0111 -print0 | xargs -0 sed -i -e "s/${PLATFORM_LOC//\//\\/}/@@SDK_PATH_PLACEHOLDER@@/g"

echo "Creating archive..."
tar cJf sdk-${MACHINE}.tar.xz sdk-${MACHINE}

mkdir ${outputDir}
mv sdk-${MACHINE}.tar.xz ${outputDir}
mv setup-environnement-${MACHINE}.sh ${outputDir}

echo "Please find SDK in ${outputDir}"


